@@ -4,10 +4,10 @@ function _aws_cdk_aws_ivs_ChannelType(p) {
 }
 function _aws_cdk_aws_ivs_PlaybackKeyPairProps(p) {
 }
-function _aws_cdk_aws_ivs_IStreamKey(p) {
-}
 function _aws_cdk_aws_ivs_IPlaybackKeyPair(p) {
 }
+function _aws_cdk_aws_ivs_IStreamKey(p) {
+}
 function _aws_cdk_aws_ivs_StreamKeyProps(p) {
     if (p == null)
         return;
@@ -50,10 +50,10 @@ function _aws_cdk_aws_ivs_CfnRecordingConfigurationProps(p) {
         require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
     visitedObjects.delete(p);
 }
-function _aws_cdk_aws_ivs_PlaybackKeyPair(p) {
-}
 function _aws_cdk_aws_ivs_StreamKey(p) {
 }
+function _aws_cdk_aws_ivs_PlaybackKeyPair(p) {
+}
 function _aws_cdk_aws_ivs_ChannelProps(p) {
     if (p == null)
         return;
@@ -93,5 +93,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_ivs_LatencyMode, _aws_cdk_aws_ivs_ChannelType, _aws_cdk_aws_ivs_PlaybackKeyPairProps, _aws_cdk_aws_ivs_IStreamKey, _aws_cdk_aws_ivs_IPlaybackKeyPair, _aws_cdk_aws_ivs_StreamKeyProps, _aws_cdk_aws_ivs_CfnStreamKeyProps, _aws_cdk_aws_ivs_CfnPlaybackKeyPairProps, _aws_cdk_aws_ivs_IChannel, _aws_cdk_aws_ivs_CfnChannelProps, _aws_cdk_aws_ivs_CfnRecordingConfigurationProps, _aws_cdk_aws_ivs_PlaybackKeyPair, _aws_cdk_aws_ivs_StreamKey, _aws_cdk_aws_ivs_ChannelProps, _aws_cdk_aws_ivs_CfnPlaybackKeyPair, _aws_cdk_aws_ivs_CfnStreamKey, _aws_cdk_aws_ivs_Channel, _aws_cdk_aws_ivs_CfnChannel, _aws_cdk_aws_ivs_CfnRecordingConfiguration, _aws_cdk_aws_ivs_CfnRecordingConfiguration_S3DestinationConfigurationProperty, _aws_cdk_aws_ivs_CfnRecordingConfiguration_DestinationConfigurationProperty };
+module.exports = { print, _aws_cdk_aws_ivs_LatencyMode, _aws_cdk_aws_ivs_ChannelType, _aws_cdk_aws_ivs_PlaybackKeyPairProps, _aws_cdk_aws_ivs_IPlaybackKeyPair, _aws_cdk_aws_ivs_IStreamKey, _aws_cdk_aws_ivs_StreamKeyProps, _aws_cdk_aws_ivs_CfnStreamKeyProps, _aws_cdk_aws_ivs_CfnPlaybackKeyPairProps, _aws_cdk_aws_ivs_IChannel, _aws_cdk_aws_ivs_CfnChannelProps, _aws_cdk_aws_ivs_CfnRecordingConfigurationProps, _aws_cdk_aws_ivs_StreamKey, _aws_cdk_aws_ivs_PlaybackKeyPair, _aws_cdk_aws_ivs_ChannelProps, _aws_cdk_aws_ivs_CfnPlaybackKeyPair, _aws_cdk_aws_ivs_CfnStreamKey, _aws_cdk_aws_ivs_Channel, _aws_cdk_aws_ivs_CfnChannel, _aws_cdk_aws_ivs_CfnRecordingConfiguration, _aws_cdk_aws_ivs_CfnRecordingConfiguration_S3DestinationConfigurationProperty, _aws_cdk_aws_ivs_CfnRecordingConfiguration_DestinationConfigurationProperty };
 module.exports.DeprecationError = DeprecationError;
